@@ -93,7 +93,6 @@ async def ingest_data_func(
     kb_resource_id,
     tenant_resource_id,
     namespace,
-    category,
     batch,
     **kwargs
 ):
@@ -102,7 +101,6 @@ async def ingest_data_func(
 
     form_data = aiohttp.FormData()
     form_data.add_field('namespace', namespace)
-    form_data.add_field('category', category)
     files_to_close = []
 
     timeout = aiohttp.ClientTimeout(total=600) # 10 minutes
@@ -118,6 +116,7 @@ async def ingest_data_func(
             author = data.get("author", None)
             # Creation date of the data in ISO8601 format.
             created_at = data.get("created_at", None)
+            category = data.get("category", [])
 
             if not author or not created_at:
                 raise ValueError("Author and created_at are required fields.")
@@ -127,8 +126,9 @@ async def ingest_data_func(
 
             form_data.add_field('record_id', id)
             form_data.add_field('local_str', "ja_JP")
-            form_data.add_field('author', author)
+            form_data.add_field('authors', author)
             form_data.add_field('created_at', iso_created_at)
+            form_data.add_field('tags', category)
 
             if text is not None:
                 form_data.add_field('text', text)
@@ -330,6 +330,7 @@ async def delete_item_func(
     tenant_id,
     kb_resource_id,
     record_ids=[],
+    namespace=None,
     **kwargs
 ):
     if not record_ids:
@@ -338,6 +339,7 @@ async def delete_item_func(
     url = f"{kwargs['base_url']}/stores/{tenant_id}/knowledge-bases/{kb_resource_id}"
     logger.info(f"Endpoint URL: {url}")
     params = [("record_id", rec_id) for rec_id in record_ids]
+    params.append(('namespace', namespace))
 
     async with aiohttp.ClientSession() as session:
         async with rate_limiter:
@@ -393,27 +395,69 @@ async def get_kb_records_func(
     kb_resource_id,
     record_ids=[],
     namespace=None,
+    includes=[],
+    status=[],
+    limit=50,
+    tags=[],
+    offset=0,
+    creation_from=None,
+    creation_to=None,
     **kwargs
 ):
     url = f"{kwargs['base_url']}/stores/{tenant_id}/knowledge-bases/{kb_resource_id}"
     
     # Correctly format the query parameters with multiple `ids[]`
     params = [('record_id', record_id) for record_id in record_ids]
-    params.append(('limit', 0))
     params.append(('namespace', namespace))
+    params.extend([('include', include) for include in includes])
+    params.extend([('status', stat) for stat in status])
+    params.append(('limit', limit))
+    params.extend([('tag', tag) for tag in tags])
+    params.append(('offset', offset))
+    if creation_from:
+        params.append(('creation_from', creation_from))
+    if creation_to:
+        params.append(('creation_to', creation_to))
 
     for param in params:
         logger.info(f"Query parameter: {param}")
 
+    # async with aiohttp.ClientSession() as session:
+    #     async with rate_limiter:
+    #         res = await session.get(url, headers=kwargs['headers'], params=params, ssl=ssl_context)
+    #         if res.status != 401:
+    #             result = await PollTaskStatusNamespace.poll_task_status_handler(
+    #                 res,
+    #                 status_url="https://192.168.20.20/api/v1/tasks/status",
+    #                 task_id_key='task_token',
+    #                 **kwargs
+    #             )
+    #             return result
+    #         return res
+
     async with aiohttp.ClientSession() as session:
         async with rate_limiter:
-            res = await session.get(url, headers=kwargs['headers'], params=params, ssl=ssl_context)
-            if res.status != 401:
-                result = await PollTaskStatusNamespace.poll_task_status_handler(
-                    res,
-                    status_url="https://192.168.20.20/api/v1/tasks/status",
-                    task_id_key='task_token',
-                    **kwargs
-                )
-                return result
-            return res
\ No newline at end of file
+            return await session.get(url, headers=kwargs['headers'], params=params, ssl=ssl_context)
+
+
+@retry_on_client_error()
+@token_refresh_handler
+@log_and_authorize
+@HTTPStatusHandler(200)
+async def get_namespace_metadata_func(
+    tenant_resource_id,
+    kb_resource_id,
+    namespace,
+    **kwargs
+):
+    url = f"{kwargs['base_url']}/stores/{tenant_resource_id}/knowledge-bases/{kb_resource_id}/namespaces/{namespace}"
+
+    # Params: include=authors&include=tags
+    params = {
+        "include": "authors,tags"
+    }
+    logger.info(f"Params: {params}")
+
+    async with aiohttp.ClientSession() as session:
+        async with rate_limiter:
+            return await session.get(url, headers=kwargs['headers'], params=params, ssl=ssl_context)
