@@ -126,7 +126,7 @@ class KnowledgeBase(BaseMultiModalRag, AbstractKnowledgeBaseHandler, _Role):
             **kwargs
         )
 
-        logger.info("KnowledgeBase: ingest_data response: %s", result)
+        # logger.info("KnowledgeBase: ingest_data response: %s", result)
         return result
 
     @_inject_params
@@ -179,11 +179,13 @@ class KnowledgeBase(BaseMultiModalRag, AbstractKnowledgeBaseHandler, _Role):
         self,
         kb_resource_id,
         record_ids,
+        namespace=None,
         **kwargs
     ):
         result = await delete_item_func(
             kb_resource_id=kb_resource_id,
             record_ids=record_ids,
+            namespace=namespace,
             **kwargs
         )
 
@@ -210,8 +212,8 @@ class KnowledgeBase(BaseMultiModalRag, AbstractKnowledgeBaseHandler, _Role):
     async def get_record_ids(
         self,
         kb_resource_id,
-        record_ids,
         namespace,
+        record_ids=[],
         **kwargs
     ):
         result = await get_kb_records_func(
@@ -221,5 +223,21 @@ class KnowledgeBase(BaseMultiModalRag, AbstractKnowledgeBaseHandler, _Role):
             **kwargs
         )
 
-        logger.info("KnowledgeBase: get_record_ids response: %s", result)
+        # logger.info("KnowledgeBase: get_record_ids response: %s", result)
+        return result
+    
+    @_inject_params
+    async def get_namespace_metadata(
+        self,
+        kb_resource_id,
+        namespace,
+        **kwargs
+    ):
+        result = await get_namespace_metadata_func(
+            kb_resource_id=kb_resource_id,
+            namespace=namespace,
+            **kwargs
+        )
+
+        logger.info("KnowledgeBase: get_namespace_metadata response: %s", result)
         return result
\ No newline at end of file
