@@ -124,9 +124,9 @@ async def main():
     user_handler = UserHandler()
 
     login_user = await user_handler.login(
-        username="mwmasoomraj",
+        username="mwtestuser002",
         # username="mwtoyo_2312",
-        password="Tokyo@6377300390"
+        password="Microwave@2025"
     )
     logger.info("login_user final response (mwtoyo_2312): %s", login_user)
 
@@ -185,11 +185,19 @@ async def main():
 
     # Get records
     # response = await kb.get_record_ids(
-    #     kb_resource_id="4998eae9-ec70-4c3e-834d-4a53bbd10253",
+    #     tenant_id="microwave-test-001",
+    #     kb_resource_id="microwave-digital-test",
     #     access_token=access_token_123,
     #     refresh_token=refresh_token_123,
-    #     record_ids=["1739265561.046389"],
-    #     namespace="rag-test-masoom",
+    #     # record_ids=["1739265561.046389"],
+    #     namespace="new-ingestion-test",
+    #     includes=["tags", "summaries", "links"],
+    #     # status=["draft"],
+    #     # limit=50,
+    #     # tags=["raw_text"],
+    #     offset=1,
+    #     creation_from="2025-08-21T00:00:00Z", # In ISO 8601 format
+    #     creation_to="2025-09-30T23:59:59Z"
     # )
     # logger.info("get_record_ids response: %s", response)
 
